"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableDataFormDataBuilder = void 0;
var TableDataFormDataBuilder = (function () {
    function TableDataFormDataBuilder(_formDataFactory, _formParts) {
        if (_formParts === void 0) { _formParts = {}; }
        this._formDataFactory = _formDataFactory;
        this._formParts = _formParts;
    }
    TableDataFormDataBuilder.prototype.withColumnGroups = function (groups) {
        var _this = this;
        if (groups) {
            var groupsCount_1 = 0;
            groups.forEach(function (group, i) {
                _this._formParts["group".concat(i)] = group;
                groupsCount_1++;
            });
            this._formParts['groupscount'] = "".concat(groupsCount_1);
        }
        return this;
    };
    TableDataFormDataBuilder.prototype.withFilterGroups = function (groups) {
        var _this = this;
        if (groups) {
            var filtersCount_1 = 0;
            groups.forEach(function (group) {
                if (group.filters.length) {
                    group.filters.forEach(function (filter, i) {
                        var _a, _b;
                        var firstFilter = i === 0;
                        var lastFilter = i === group.filters.length - 1;
                        _this._formParts["filtergroupopen".concat(filtersCount_1)] = firstFilter ? '1' : '0';
                        _this._formParts["filteroperator".concat(filtersCount_1)] = firstFilter ? (_a = group.groupOperator) === null || _a === void 0 ? void 0 : _a.value : (_b = group.filterOperator) === null || _b === void 0 ? void 0 : _b.value;
                        _this._formParts["filterdatafield".concat(filtersCount_1)] = filter.filterDataField;
                        _this._formParts["filtercondition".concat(filtersCount_1)] = filter.filterCondition;
                        _this._formParts["filtervalue".concat(filtersCount_1)] = filter.filterValue.toString();
                        _this._formParts["filtergroupclose".concat(filtersCount_1)] = lastFilter ? '1' : '0';
                        filtersCount_1++;
                    });
                }
            });
            this._formParts['filterscount'] = "".concat(filtersCount_1);
        }
        return this;
    };
    TableDataFormDataBuilder.prototype.withPage = function (page) {
        if (page === void 0) { page = 0; }
        this._formParts.pagenum = "".concat(page);
        return this;
    };
    TableDataFormDataBuilder.prototype.withPageSize = function (pageSize) {
        if (pageSize === void 0) { pageSize = 10; }
        this._formParts.pagesize = "".concat(pageSize);
        return this;
    };
    TableDataFormDataBuilder.prototype.withSortColumn = function (sortColumn) {
        if (sortColumn) {
            this._formParts.sortdatafield = sortColumn;
        }
        return this;
    };
    TableDataFormDataBuilder.prototype.withSortOrder = function (sortOrder) {
        if (sortOrder) {
            this._formParts.sortorder = sortOrder;
        }
        return this;
    };
    TableDataFormDataBuilder.prototype.withDatabase = function (database) {
        if (database) {
            this._formParts.database = database;
        }
        return this;
    };
    TableDataFormDataBuilder.prototype.entries = function () {
        return this._formParts;
    };
    TableDataFormDataBuilder.prototype.build = function () {
        var formData = this._formDataFactory();
        Object.entries(this._formParts).forEach(function (urlPart) { return formData.append(urlPart[0], "".concat(urlPart[1])); });
        return formData;
    };
    return TableDataFormDataBuilder;
}());
exports.TableDataFormDataBuilder = TableDataFormDataBuilder;
//# sourceMappingURL=table-data-form-data-builder.js.map