import { bugsplatAppHostUrl } from '../../index';
import { BugSplatAuthenticationError } from '../api-client';
export class OAuthClientCredentialsClient {
    _clientId;
    _clientSecret;
    _host;
    _accessToken = '';
    _tokenType = '';
    _createFormData = () => new FormData();
    _fetch = globalThis.fetch;
    constructor(_clientId, _clientSecret, _host = bugsplatAppHostUrl) {
        this._clientId = _clientId;
        this._clientSecret = _clientSecret;
        this._host = _host;
    }
    static async createAuthenticatedClient(clientId, clientSecret, host = bugsplatAppHostUrl) {
        const client = new OAuthClientCredentialsClient(clientId, clientSecret, host);
        await client.login();
        return client;
    }
    async login() {
        const route = '/oauth2/authorize';
        const method = 'POST';
        const body = this.createFormData();
        body.append('grant_type', 'client_credentials');
        body.append('client_id', this._clientId);
        body.append('client_secret', this._clientSecret);
        body.append('scope', 'restricted');
        const request = {
            method,
            body,
            duplex: 'half'
        };
        const response = await this.fetch(route, request);
        const responseJson = await response.json();
        if (responseJson.error === 'invalid_client') {
            throw new BugSplatAuthenticationError('Could not authenticate, check credentials and try again');
        }
        const loginResponse = responseJson;
        this._accessToken = loginResponse.access_token;
        this._tokenType = loginResponse.token_type;
        return response;
    }
    createFormData() {
        return this._createFormData();
    }
    async fetch(route, init) {
        const url = new URL(route, this._host);
        init = init ?? {};
        if (!init.headers) {
            init.headers = {};
        }
        init.headers['Authorization'] = `${this._tokenType} ${this._accessToken}`;
        const response = await this._fetch(url.href, init);
        const status = response.status;
        const body = response.body;
        if (status === 401) {
            throw new BugSplatAuthenticationError('Could not authenticate, check credentials and try again');
        }
        return {
            status,
            body,
            json: async () => response.clone().json(),
            text: async () => response.clone().text()
        };
    }
}
//# sourceMappingURL=oauth-client-credentials-api-client.js.map