import ac from 'argument-contracts';
import { createCrashDetails } from '../crash-details/crash-details';
export class CrashApiClient {
    _client;
    constructor(_client) {
        this._client = _client;
    }
    async getCrashById(database, crashId) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (crashId <= 0) {
            throw new Error(`Expected id to be a positive non-zero number. Value received: "${crashId}"`);
        }
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('id', crashId.toString());
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            duplex: 'half'
        };
        const response = await this._client.fetch('/api/crash/details', init);
        const json = await response.json();
        if (response.status !== 200) {
            throw new Error(json.message);
        }
        return createCrashDetails(json);
    }
    async reprocessCrash(database, crashId, force = false, processor = '') {
        return this.reprocessCrashes(database, [crashId], force, processor);
    }
    async reprocessCrashes(database, crashIds, force = false, processor = '') {
        ac.assertNonWhiteSpaceString(database, 'database');
        ac.assertBoolean(force, 'force');
        for (const crashId of crashIds) {
            if (crashId <= 0) {
                throw new Error(`Expected ids to be positive non-zero numbers. Value received: "${crashId}"`);
            }
        }
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('id', crashIds.join(','));
        formData.append('force', force.toString());
        if (processor) {
            formData.append('processor', processor);
        }
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            duplex: 'half'
        };
        const response = await this._client.fetch('/api/crash/reprocess', init);
        const json = await response.json();
        if (response.status !== 202) {
            throw new Error(json.message);
        }
        return json;
    }
    async postStatus(database, groupId, status) {
        ac.assertNonWhiteSpaceString(database, 'database');
        ac.assertNumber(groupId, 'groupId');
        ac.assertNumber(status, 'status');
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('groupId', groupId.toString());
        formData.append('status', status.toString());
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            duplex: 'half'
        };
        const response = await this._client.fetch('/api/crash/status', init);
        const json = await response.json();
        if (response.status !== 200) {
            throw new Error(json.message);
        }
        return json;
    }
}
//# sourceMappingURL=crash-api-client.js.map