import { AdditionalInfo, GroupableThreadCollection, ThreadCollection } from '../index';
import ac from 'argument-contracts';
import { safeParseJson } from '../../common/parse';
import { createEvents } from '../../events/events-api-client/event';
export var ProcessingStatus;
(function (ProcessingStatus) {
    ProcessingStatus[ProcessingStatus["Processing"] = 0] = "Processing";
    ProcessingStatus[ProcessingStatus["ActiveThreadComplete"] = 1] = "ActiveThreadComplete";
    ProcessingStatus[ProcessingStatus["Complete"] = 2] = "Complete";
})(ProcessingStatus || (ProcessingStatus = {}));
export var DefectTrackerType;
(function (DefectTrackerType) {
    DefectTrackerType["None"] = "None";
    DefectTrackerType["FogBugz"] = "FogBugz";
    DefectTrackerType["Jira"] = "Jira";
    DefectTrackerType["Azure"] = "Azure DevOps";
    DefectTrackerType["YouTrack"] = "YouTrack";
    DefectTrackerType["GitHub"] = "GitHub";
    DefectTrackerType["Assembla"] = "Assembla";
    DefectTrackerType["Monday"] = "Monday";
    DefectTrackerType["GitLab"] = "GitLab";
    DefectTrackerType["Favro"] = "Favro";
})(DefectTrackerType || (DefectTrackerType = {}));
export var CrashStatus;
(function (CrashStatus) {
    CrashStatus[CrashStatus["Open"] = 0] = "Open";
    CrashStatus[CrashStatus["Closed"] = 1] = "Closed";
    CrashStatus[CrashStatus["Regression"] = 2] = "Regression";
})(CrashStatus || (CrashStatus = {}));
export function createCrashDetails(options) {
    ac.assertNumber(options.processed, 'options.processed');
    ac.assertNumber(options.id, 'options.id');
    ac.assertNumber(options.stackKeyId, 'options.stackKeyId');
    ac.assertBoolean(options.missingSymbols, 'options.missingSymbols');
    ac.assertNumber(options.dumpfileSize, 'options.dumpfileSize');
    const appName = defaultToEmptyString(options.appName, 'options.appName');
    const appVersion = defaultToEmptyString(options.appVersion, 'options.appVersion');
    const appKey = defaultToEmptyString(options.appKey, 'options.appKey');
    const attributes = safeParseJson(options.attributes);
    const comments = defaultToEmptyString(options.comments, 'options.comments');
    const crashTime = defaultToEmptyString(options.crashTime, 'options.crashTime');
    const defectLabel = defaultToEmptyString(options.defectLabel, 'options.defectLabel');
    const defectUrl = defaultToEmptyString(options.defectUrl, 'options.defectUrl');
    const description = defaultToEmptyString(options.description, 'options.description');
    const dumpfile = defaultToEmptyString(options.dumpfile, 'options.dumpfile');
    const email = defaultToEmptyString(options.email, 'options.email');
    const exceptionCode = defaultToEmptyString(options.exceptionCode, 'options.exceptionCode');
    const exceptionMessage = defaultToEmptyString(options.exceptionMessage, 'options.exceptionMessage');
    const ipAddress = defaultToEmptyString(options.ipAddress, 'options.ipAddress');
    const platform = defaultToEmptyString(options.platform, 'options.platform');
    const processor = defaultToEmptyString(options.processor, 'options.processor');
    const stackKey = defaultToEmptyString(options.stackKey, 'options.stackKey');
    const stackKeyComment = defaultToEmptyString(options.stackKeyComment, 'options.stackKeyComment');
    const stackKeyDefectLabel = defaultToEmptyString(options.stackKeyDefectLabel, 'options.stackKeyDefectLabel');
    const stackKeyDefectUrl = defaultToEmptyString(options.stackKeyDefectUrl, 'options.stackKeyDefectUrl');
    const user = defaultToEmptyString(options.user, 'options.user');
    ac.assertType(options.thread, ThreadCollection, 'options.thread');
    ac.assertType(options.events, Array, 'options.events');
    const status = (options.status || 0);
    const events = createEvents(options.events);
    const thread = new GroupableThreadCollection({
        ...options.thread,
        stackKeyId: options.stackKeyId,
    });
    const additionalInfo = AdditionalInfo.fromRawResponse(options.debuggerOutput);
    return {
        ...options,
        appKey,
        appName,
        appVersion,
        attributes,
        comments,
        crashTime,
        defectLabel,
        defectUrl,
        description,
        dumpfile,
        email,
        exceptionCode,
        exceptionMessage,
        ipAddress,
        platform,
        processor,
        status,
        stackKey,
        stackKeyComment,
        stackKeyDefectLabel,
        stackKeyDefectUrl,
        user,
        thread,
        additionalInfo,
        events,
    };
}
function defaultToEmptyString(value, name) {
    if (value) {
        ac.assertString(value, name);
        return value;
    }
    else {
        return '';
    }
}
//# sourceMappingURL=crash-details.js.map