import { TableDataClient, } from '../../common/index';
import { CrashesApiRow } from '../index';
export class CrashesApiClient {
    _client;
    _tableDataClient;
    constructor(_client) {
        this._client = _client;
        this._tableDataClient = new TableDataClient(this._client, '/api/crashes.php');
    }
    async deleteCrashes(database, ids) {
        const urlParams = new URLSearchParams({ database, ids: ids.join(',') });
        const request = {
            method: 'DELETE',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            duplex: 'half',
        };
        return this._client.fetch(`/api/crashes.php?${urlParams}`, request);
    }
    async getCrashes(request) {
        const response = await this._tableDataClient.postGetData(request);
        const json = await response.json();
        const pageData = json.pageData;
        const rows = json.rows.map((row) => new CrashesApiRow(row));
        return {
            rows,
            pageData,
        };
    }
    postNotes(database, id, notes) {
        const formData = this._client.createFormData();
        formData.append('update', 'true');
        formData.append('database', database);
        formData.append('id', `${id}`);
        formData.append('Comments', notes);
        const request = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            duplex: 'half',
        };
        return this._client.fetch('/browse/allcrash.php', request);
    }
}
//# sourceMappingURL=crashes-api-client.js.map