import { TableDataClient } from '../../common/index';
import { CrashesApiRow } from '../index';
import { createKeyCrashPageData } from './key-crash-page-data';
export class KeyCrashApiClient {
    _client;
    _tableDataClient;
    constructor(_client) {
        this._client = _client;
        this._tableDataClient = new TableDataClient(this._client, '/keycrash?data&crashTimeSpan');
    }
    async getCrashes(request) {
        const formParts = { stackKeyId: `${request.stackKeyId}` };
        const response = await this._tableDataClient.postGetData(request, formParts);
        const json = await response.json();
        const pageData = createKeyCrashPageData(json.pageData);
        const rows = json.rows.map(row => new CrashesApiRow(row));
        return {
            rows,
            pageData
        };
    }
    postNotes(database, stackKeyId, notes) {
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('stackKeyId', stackKeyId.toString());
        formData.append('stackKeyComment', notes);
        const request = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            duplex: 'half'
        };
        return this._client.fetch('/api/stackKeyComment.php', request);
    }
}
//# sourceMappingURL=key-crash-api-client.js.map