import ac from 'argument-contracts';
import { createEvents } from './event';
export class EventsApiClient {
    _client;
    constructor(_client) {
        this._client = _client;
    }
    getEventsForCrashId(database, crashId) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (crashId <= 0) {
            throw new Error(`Expected crashId to be a positive non-zero number. Value received: "${crashId}"`);
        }
        return this.getEvents(`/api/events?database=${database}&crashId=${crashId}`);
    }
    getEventsForStackKeyId(database, stackKeyId) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (stackKeyId <= 0) {
            throw new Error(`Expected crashId to be a positive non-zero number. Value received: "${stackKeyId}"`);
        }
        return this.getEvents(`/api/events?database=${database}&stackKeyId=${stackKeyId}`);
    }
    postCrashComment(database, crashId, comment) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (crashId <= 0) {
            throw new Error(`Expected crashId to be a positive non-zero number. Value received: "${crashId}"`);
        }
        const method = 'POST';
        const body = this._client.createFormData();
        const duplex = 'half';
        body.append('database', database);
        body.append('crashId', `${crashId}`);
        body.append('message', comment);
        return this._client.fetch('/api/events/comment', {
            method,
            body,
            duplex
        });
    }
    postStackKeyComment(database, stackKeyId, comment) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (stackKeyId <= 0) {
            throw new Error(`Expected stackKeyId to be a positive non-zero number. Value received: "${stackKeyId}"`);
        }
        const method = 'POST';
        const body = this._client.createFormData();
        const duplex = 'half';
        body.append('database', database);
        body.append('stackKeyId', `${stackKeyId}`);
        body.append('message', comment);
        return this._client.fetch('/api/events/comment', {
            method,
            body,
            duplex
        });
    }
    async getEvents(route) {
        const response = await this._client.fetch(route);
        const json = await response.json();
        if (response.status !== 200) {
            throw new Error(json.message);
        }
        return createEvents(json.events);
    }
}
//# sourceMappingURL=events-api-client.js.map