const USERS_BASE_URL = '/api/user/users.php';
export class UsersApiClient {
    _client;
    constructor(_client) {
        this._client = _client;
    }
    async getUsers(request) {
        const { database, companyId, email } = request;
        if (database && companyId) {
            throw new Error('Cannot specify both database and companyId');
        }
        if (!database && !companyId) {
            throw new Error('Must specify either database or companyId');
        }
        const params = new URLSearchParams();
        if (database) {
            params.append('database', database);
        }
        if (companyId) {
            params.append('companyId', companyId.toString());
        }
        if (email) {
            params.append('username', email);
        }
        const url = `${USERS_BASE_URL}?${params.toString()}`;
        const response = await this._client.fetch(url);
        const rows = await response.json();
        return {
            rows,
        };
    }
    async addUserToDatabase(database, email) {
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('username', email);
        const request = {
            method: 'POST',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            body: formData,
        };
        const response = await this._client.fetch(USERS_BASE_URL, request);
        if (response.status !== 200) {
            throw new Error(`Error adding user ${email} to database ${database} status ${response.status}`);
        }
        return response;
    }
    async removeUserFromDatabase(database, email) {
        const url = `${USERS_BASE_URL}?database=${database}&username=${encodeURIComponent(email)}`;
        const request = {
            method: 'DELETE',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
        };
        const response = await this._client.fetch(url, request);
        if (response.status !== 200) {
            throw new Error(`Error remove user ${email} for ${database} status ${response.status}`);
        }
        return response;
    }
    async updateUserForDatabase(database, email, isRestricted) {
        const rights = isRestricted ? '0' : '1';
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('username', email);
        formData.append('rights', rights);
        const request = {
            method: 'POST',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            body: formData,
        };
        const response = await this._client.fetch(USERS_BASE_URL, request);
        if (response.status !== 200) {
            throw new Error(`Error updating user ${email} in database ${database} status ${response.status}`);
        }
        return response;
    }
    async addUserToCompany(companyId, email) {
        const formData = this._client.createFormData();
        formData.append('companyId', companyId.toString());
        formData.append('username', email);
        const request = {
            method: 'POST',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
            body: formData,
        };
        const response = await this._client.fetch(USERS_BASE_URL, request);
        if (response.status !== 200) {
            throw new Error(`Error adding user ${email} to company ${companyId} status ${response.status}`);
        }
        return response;
    }
    async removeUserFromCompany(companyId, uId) {
        const url = `${USERS_BASE_URL}?companyId=${companyId}&uId=${uId}`;
        const request = {
            method: 'DELETE',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow',
        };
        const response = await this._client.fetch(url, request);
        if (response.status !== 200) {
            throw new Error(`Error removing user ${uId} for company ${companyId} status ${response.status}`);
        }
        return response;
    }
}
export var UserApiResponseStatus;
(function (UserApiResponseStatus) {
    UserApiResponseStatus["success"] = "success";
    UserApiResponseStatus["warning"] = "warning";
    UserApiResponseStatus["fail"] = "fail";
})(UserApiResponseStatus || (UserApiResponseStatus = {}));
//# sourceMappingURL=users-api-client.js.map